@@ -1,7 +1,7 @@
 package Evo::Class;
 use Evo '-Export export_proxy; Evo::Class::Meta; Evo::Class::Base';
 
-export_proxy '::Syntax', qw(lazy rw ro optional check inject);
+export_proxy '::Syntax', qw(lazy rw ro optional check inject no_method);
 
 sub import ($me, @list) {
   my $caller = caller;
@@ -89,7 +89,7 @@ Evo::Class
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 DESCRIPTION
 
@@ -283,6 +283,20 @@ Used to describe dependencies of a class. We can build C<Foo> that depends on C<
 
 See L<Evo::Di> for more information.
 
+=head4 no_method
+
+Register an attribute but don't install method(accessor) for it.
+
+  package Foo;
+  use Evo -Class, -Loaded;
+  has foo => no_method;
+
+  package main;
+  use Evo;
+  my $obj = Foo::->new(foo => 'FOO');
+  warn $obj->{foo};    # FOO
+  warn $obj->can('foo') ? 'can' : "can't";    # can't
+
 =head1 CODE REUSE
 
 Only public functions will be inherited.
