@@ -8,7 +8,7 @@ export qw(
   ECA_OPTIONAL ECA_DEFAULT ECA_DEFAULT_CODE ECA_REQUIRED ECA_LAZY
 );
 
-our $VERSION = '0.0401';    # VERSION
+our $VERSION = '0.0402';    # VERSION
 
 # to be able to run with and without dzil
 my $version = eval '$VERSION';    ## no critic
@@ -18,6 +18,10 @@ $version
 
 sub new { bless [], shift }
 
+sub gen_attr ($self, %opts) {
+  $self->_gen_attr(@opts{qw(name type value check ro inject method)});
+}
+
 1;
 
 # ABSTRACT: XS implementation of attributes and "new" method generator
@@ -34,7 +38,7 @@ Evo::Class::Attrs::XS - XS implementation of attributes and "new" method generat
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 AUTHOR
 
