@@ -27,6 +27,12 @@ sub lazy : prototype() : Export {
   SYNTAX_STATE;
 }
 
+sub no_method() : prototype() : Export {
+  _check_settled('no_method');
+  SYNTAX_STATE()->{no_method}++;
+  SYNTAX_STATE;
+}
+
 sub ro() : prototype() : Export {
   _check_settled('ro');
   SYNTAX_STATE()->{ro}++;
@@ -64,7 +70,7 @@ Evo::Class::Syntax
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 AUTHOR
 
